'use strict'

var Promise = require("bluebird");
var AWS     = require("aws-sdk");
var crypto  = require("crypto");

const HOOROO_CIPHER_OF_CHOICE = "AES-256-CBC";

function parseConfig(rawConfig) {
  let config = {};
  rawConfig
    .toString()
    .trim()
    .split("\n")
    .forEach(function (line) {
      var matchers = line.match(/([\w|_]+)=(.*)/);
      config[matchers[1]] = matchers[2].replace(/^"(.*)"$/, '$1');
    });

  return config;
}

function decrypt(content, key, iv) {
  let cipher = crypto.createDecipheriv(HOOROO_CIPHER_OF_CHOICE, key, iv);
  return Promise.resolve(Buffer.concat([ cipher.update(content),
                                         cipher.final() ]));
}

function encrypt(content, key, iv) {
  let cipher = crypto.createCipheriv(HOOROO_CIPHER_OF_CHOICE, key, iv);
  return Promise.resolve(Buffer.concat([ cipher.update(content),
                                         cipher.final() ]));
}

function decryptConfig(contents) {
  let splits = contents.toString().split("|");

  let iv                = new Buffer(splits[1], "hex");
  let encryptedKey      = new Buffer(splits[2], "base64");
  let encryptedContents = new Buffer(splits[3], "base64");

  return new AWS.KMS().decrypt({ CiphertextBlob: encryptedKey }).promise()
            .then((key)           => { return decrypt(encryptedContents, key.Plaintext, iv) })
            .then((contentBuffer) => { return contentBuffer.toString() })
}

module.exports = { decryptConfig: decryptConfig, parseConfig: parseConfig }
